@@ -15,7 +15,7 @@
 
 There should be a file 'ftesting.zcml' in the current directory.
 
-$Id: functional.py 90208 2008-08-25 13:50:44Z fdrake $
+$Id: functional.py 92021 2008-10-10 19:09:49Z matt $
 """
 import copy
 import logging
@@ -780,14 +780,13 @@ def FunctionalDocTestSuite(*paths, **kw):
 
 def _prepare_doctest_keywords(kw):
     globs = kw.setdefault('globs', {})
-    globs['http'] = HTTPCaller()
     globs['getRootFolder'] = getRootFolder
     globs['sync'] = sync
 
     kwsetUp = kw.get('setUp')
     def setUp(test):
+	test.globs['http'] = HTTPCaller()
         FunctionalTestSetup().setUp()
-
         if kwsetUp is not None:
             kwsetUp(test)
     kw['setUp'] = setUp
